---
title: 'TopoPyScale: A Python package for hillslope climate downscaling'
tags:
  - Python
  - climate science
  - downscaling
  - xarray
  - dem segmentation
  - snow
  - permafrost
authors:
  - name: Simon Filhol
    orcid: 0000-0003-1282-7307
    corresponding: true
    equal-contrib: true
    affiliation: 1
  - name: Joel Fiddes
    orcid: 0000-0003-2870-6972
    equal-contrib: true
    affiliation: 2
  - name: Kristoffer Aalstad
    orcid: 0000-0002-2475-3731
    affiliation: 1
affiliations:
 - name: University of Oslo, Norway
   index: 1
 - name: WSL Institute for Snow and Avalanche Research SLF, Switzerland
   index: 2
date: 8 November 2022
bibliography: paper.bib
---

# Summary

Climate reanalysis or forecast models are available worldwide for extended periods of time for the twentieth and twenty first century but often spatially too course to be relevant to mountainous regions. Mountain regions are some of the regions experiencing the fastest contenporary climate change. To understand and study geomorphological, hydrological, glaciological changes, we need tools to downscale climatic timeseries for the basic atmospheric state variables used to solve energy and water mass fluxes. Advanced physically based methods exist, though they come with high computational cost and complex technical setup. `TopoPyScale` uses a pragmatic approach to downscaling to minimize complexity, reduce computational cost, simplify interaoperability with land surface models, while retaining physical coherence. 





# Statement of need

`TopoPyScale` is Python package for performing climate downscaling. It is designed as a toolbox combining methods to downscale climate reanalysis and forecast models (e.g. [@hersbachERA5GlobalReanalysis2020:2020]) . 

, and interoperable inputs and outputs





# Toolbox methods and structure

- insert here diagram figure
- describe topo_sub
- interapporabitlity with independant land-surface models



# Acknowledgements

Financial support for this project came from the XXXX grant awrad number XXXX. 

# References
